==> galaxeus_lib-0.0.42.tar.gz: lib/src/json_to_isar.dart <==
// ignore_for_file: unnecessary_brace_in_string_interps, non_constant_identifier_names
//

import 'dart:convert';
import 'package:galaxeus_lib/galaxeus_lib.dart';

JsonDataScript jsonToIsar(
  Map<String, dynamic> data, {
  String className = "Root",
  bool isMain = true,
  bool isUseClassName = false,
  String? comment,
}) {
  return JsonDataScript(
    className: className,
    datas: [
      jsonToIsarDynamic(
        data,
        className: className,
        isMain: isMain,
        isUseClassName: isUseClassName,
        comment: comment,
      ),
      """
part "${className.snakeCaseClass().toLowerCase()}.dart";
"""
    ],
    is_isar: true,
  );
}

String jsonToIsarDynamic(
  Map<String, dynamic> data, {
  String className = "Root",
  bool isMain = true,
  bool isUseClassName = false,
  String? comment,
}) {
  comment ??= "";
  List<String> classMessages = [];
  String classMessage = """
${((isMain) ? """
// ignore_for_file: non_constant_identifier_names
import 'dart:convert';
import 'package:isar/isar.dart';
part "${className.snakeCaseClass().toLowerCase()}.g.dart";

@collection""" : "@embedded")} 
class ${className} { 
  
  // Id id = Isar.autoIncrement;

""";
  String classData = """

  ${comment}
  ${className}(this.rawData) {
  
""";
  String classDataCreate = """

  ${comment}
  factory ${className}.create({

""";
  String classDataCreateJson = """{

  
""";
  String operator_data = "";
  data.forEach((key, value) {
    String nameClass = key.camelCaseClass();
    if (isUseClassName) {
      nameClass = "${className}${key.camelCaseClass()}";
    }

    if (value is String) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "String",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
    if (value is int) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "int",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    } else if (value is double) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "double",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    } else if (value is num) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "num",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
    if (value is bool) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "bool",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
    if (value is Map) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "Map",
        isClass: true,
        isUseClassName: isUseClassName,
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
      classMessages.add(jsonToIsar(
        value.cast<String, dynamic>(),
        className: nameClass,
        isMain: false,
        isUseClassName: isUseClassName,
        comment: comment,
      ).first);
    }

    if (value is List) {
      if (value.isNotEmpty) {
        if (value.first is Map) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "Map",
            isClass: true,
            isUseClassName: isUseClassName,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
          classMessages.add(
            jsonToIsar(
              (value.first as Map).cast<String, dynamic>(),
              className: nameClass,
              isMain: false,
              isUseClassName: isUseClassName,
              comment: comment,
            ).first,
          );
        }
        if (value.first is bool) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "bool",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
        if (value.first is String) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "String",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
        if (value.first is int) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "int",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        } else if (value.first is double) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "double",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        } else if (value.first is num) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "num",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
        if (value.first == null) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "Object",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
      } else {
        classMessage += textToFunctionIsar(
          key: key,
          value: value,
          className: className,
          returnType: "Object",
          isClass: false,
          isList: true,
          comment: comment,
          callback: (text) {
            classData += text;
          },
          paramFunction: (text) {
            classDataCreate += text;
          },
          paramJson: (text) {
            classDataCreateJson += text;
          },
          operatorData: (text) {
            operator_data += text;
          },
        );
      }
    }

    if (value == null) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "Object",
        isClass: false,
        isList: false,
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
  });
  // classDataCreateJson += "\n\n  }";
  // classDataCreate += "})  {";
  // classDataCreate += "\n\nreturn ${className}(${classDataCreateJson});";

  // classDataCreate += "\n\n      }";
  // classData += "\n\n    }";

  // classMessage += classData;

  // classMessage += classDataCreate;

  classMessage += """
 
  /// operator map data
   operator [](key) {
    return toJson()[key];
  }
 
  /// operator map data
  void operator []=(key, value) {
    ${operator_data}
  }

  /// return original data json
  Map toMap() {
    return toJson();
  }

  /// return original data json
  Map toJson() {
    
    return 
      ${classDataCreateJson}
    };
  }

  /// return string data encode json original data
  @override
  String toString() {
    return json.encode(toJson());
  }

}""";

  classMessage += "\n\n${classMessages.join("\n\n")}";
  return classMessage;
}

String textToFunctionIsar({
  required String key,
  required value,
  required String returnType,
  required String className,
  bool isClass = false,
  bool isList = false,
  bool isUseClassName = false,
  String? comment,
  required void Function(String text) callback,
  required void Function(String text) paramFunction,
  required void Function(String text) paramJson,
  required void Function(String text) operatorData,
}) {
  comment ??= "";
  if (value is String) {
    value = json.encode(value);
  }
  String nameClass = key.camelCaseClass();
  if (isUseClassName) {
    nameClass = "${className}${key.camelCaseClass()}";
  }

  String nameMethod = key.replaceAll(RegExp(r"^(@|[0-9]+)", caseSensitive: false), "special_");

//   operatorData.call("""

//     if (key == "${key}") {
//       ${nameMethod} = value;
//     }

// """);

  if (isClass) {
    if (isList) {
      operatorData.call("""


    if (key == "${key}") {
      if (value is List<${nameClass}>) {
        ${nameMethod} = value;
      } else {
        
        ${nameMethod} = (value as List).map((state_data_procces) {
          ${nameClass} state_value_procces = ${nameClass}();
          (value as Map).forEach((key, value) {
            state_value_procces[key] = value;
          });
          return state_value_procces;
        }).toList().cast<${nameClass}>();

      }
    }


""");
      paramFunction.call("""
      List<${nameClass}?>? ${nameMethod},
""");
      paramJson.call("""
      "${key}": ${nameMethod}.map((res) => res.toJson().toList().cast<Map>(): null,
""");
      callback.call("""
      try {
        if (rawData["${key}"] is List == false){
          ${nameMethod}  = null;
        }
        ${nameMethod} = (rawData["${key}"] as List).map((e) => ${nameClass}(e as $returnType)).toList().cast<${nameClass}>();
      } catch (e) {
        ${nameMethod}  = null;
      }
""");
      return """
  ${comment}
  List<${nameClass}> ${nameMethod} = [];

""";
    }
    operatorData.call("""


    if (key == "${key}") {
      ${nameMethod} = value;
    }


    if (key == "${key}") {
      if (value is ${nameClass}) {
        ${nameMethod} = value;
      } else {
        ${nameMethod} state_value_procces = ${nameMethod}();
        (value as Map).forEach((key, value) {
          state_value_procces[key] = value;
        });
        ${nameMethod} = state_value_procces;
      }
    }


""");
    paramFunction.call("""
      ${nameClass}? ${nameMethod},
""");
    paramJson.call("""
      "${key}": (${nameMethod} != null)?${nameMethod}.toJson(): null,
""");
    callback.call("""
      try {
        if (rawData["${key}"] is ${returnType} == false){
          ${nameMethod}  =  ${nameClass}({});
        }
        ${nameMethod} = ${nameClass}(rawData["${key}"] as $returnType);
      } catch (e) {
        ${nameMethod}  = ${nameClass}({}); 
      }
""");
    return """

  ${comment}
  ${nameClass} ${nameMethod} = ${nameClass}();

""";
  }

  operatorData.call("""


    if (key == "${key}") {
      ${nameMethod} = value;
    }


""");

  if (isList) {
    paramFunction.call("""
      List<${returnType}?>? ${nameMethod},
""");
    paramJson.call("""
      "${key}": ${nameMethod},
""");
    callback.call("""
      try {
        if (rawData["${key}"] is List == false){
          ${nameMethod}  = null;
        }
        ${nameMethod} = (rawData["${key}"] as List).cast<${returnType}>();
      } catch (e) {
        ${nameMethod}  = null;
      }
""");
    return """

  ${comment}
  List<${returnType}> ${nameMethod} = ${value};

""";
  }

  paramFunction.call("""
    $returnType? ${nameMethod},
""");
  paramJson.call("""
      "${key}": ${nameMethod},
""");
  callback.call("""
      try {
        if (rawData["${key}"] is ${returnType} == false){
          ${nameMethod}  = null;
        }
        ${nameMethod} = rawData["${key}"] as ${returnType};
      } catch (e) {
        ${nameMethod}  = null;
      }
""");
  return """

  ${comment}
  $returnType ${nameMethod} = ${value};

""";
}

==> galaxeus_lib-0.0.50.tar.gz: lib/src/json_to_isar.dart <==
// ignore_for_file: unnecessary_brace_in_string_interps, non_constant_identifier_names
//

import 'dart:convert';
import 'package:galaxeus_lib/galaxeus_lib.dart';

JsonDataScript jsonToIsar(
  Map<String, dynamic> data, {
  String className = "Root",
  bool isMain = true,
  bool isUseClassName = false,
  String? comment,
}) {
  return JsonDataScript(
    className: className,
    datas: [
      jsonToIsarDynamic(
        data,
        className: className,
        isMain: isMain,
        isUseClassName: isUseClassName,
        comment: comment,
      ),
      """
part "${className.snakeCaseClass().toLowerCase()}.dart";
"""
    ],
    is_isar: true,
  );
}

String jsonToIsarDynamic(
  Map<String, dynamic> data, {
  String className = "Root",
  bool isMain = true,
  bool isUseClassName = false,
  String? comment,
}) {
  comment ??= "";
  List<String> classMessages = [];
  String classMessage = """
${((isMain) ? """
// ignore_for_file: non_constant_identifier_names
import 'dart:convert';
import 'package:isar/isar.dart';
part "${className.snakeCaseClass().toLowerCase()}.g.dart";

@collection""" : "@embedded")} 
class ${className} { 
  
  // Id id = Isar.autoIncrement;

""";
  String classData = """

  ${comment}
  ${className}(this.rawData) {
  
""";
  String classDataCreate = """

  ${comment}
  factory ${className}.create({

""";
  String classDataCreateJson = """{

  
""";
  String operator_data = "";
  data.forEach((key, value) {
    String nameClass = key.camelCaseClass();
    if (isUseClassName) {
      nameClass = "${className}${key.camelCaseClass()}";
    }

    if (value is String) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "String",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
    if (value is int) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "int",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    } else if (value is double) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "double",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    } else if (value is num) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "num",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
    if (value is bool) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "bool",
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
    if (value is Map) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "Map",
        isClass: true,
        isUseClassName: isUseClassName,
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
      classMessages.add(jsonToIsar(
        value.cast<String, dynamic>(),
        className: nameClass,
        isMain: false,
        isUseClassName: isUseClassName,
        comment: comment,
      ).first);
    }

    if (value is List) {
      if (value.isNotEmpty) {
        if (value.first is Map) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "Map",
            isClass: true,
            isUseClassName: isUseClassName,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
          classMessages.add(
            jsonToIsar(
              (value.first as Map).cast<String, dynamic>(),
              className: nameClass,
              isMain: false,
              isUseClassName: isUseClassName,
              comment: comment,
            ).first,
          );
        }
        if (value.first is bool) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "bool",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
        if (value.first is String) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "String",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
        if (value.first is int) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "int",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        } else if (value.first is double) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "double",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        } else if (value.first is num) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "num",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
        if (value.first == null) {
          classMessage += textToFunctionIsar(
            key: key,
            value: value,
            className: className,
            returnType: "Object",
            isClass: false,
            isList: true,
            comment: comment,
            callback: (text) {
              classData += text;
            },
            paramFunction: (text) {
              classDataCreate += text;
            },
            paramJson: (text) {
              classDataCreateJson += text;
            },
            operatorData: (text) {
              operator_data += text;
            },
          );
        }
      } else {
        classMessage += textToFunctionIsar(
          key: key,
          value: value,
          className: className,
          returnType: "Object",
          isClass: false,
          isList: true,
          comment: comment,
          callback: (text) {
            classData += text;
          },
          paramFunction: (text) {
            classDataCreate += text;
          },
          paramJson: (text) {
            classDataCreateJson += text;
          },
          operatorData: (text) {
            operator_data += text;
          },
        );
      }
    }

    if (value == null) {
      classMessage += textToFunctionIsar(
        key: key,
        value: value,
        className: className,
        returnType: "Object",
        isClass: false,
        isList: false,
        comment: comment,
        callback: (text) {
          classData += text;
        },
        paramFunction: (text) {
          classDataCreate += text;
        },
        paramJson: (text) {
          classDataCreateJson += text;
        },
        operatorData: (text) {
          operator_data += text;
        },
      );
    }
  });
  // classDataCreateJson += "\n\n  }";
  // classDataCreate += "})  {";
  // classDataCreate += "\n\nreturn ${className}(${classDataCreateJson});";

  // classDataCreate += "\n\n      }";
  // classData += "\n\n    }";

  // classMessage += classData;

  // classMessage += classDataCreate;

  classMessage += """
 
  /// operator map data
   operator [](key) {
    return toJson()[key];
  }
 
  /// operator map data
  void operator []=(key, value) {
    ${operator_data}
  }

  /// return original data json
  Map toMap() {
    return toJson();
  }

  /// return original data json
  Map toJson() {
    
    return 
      ${classDataCreateJson}
    };
  }

  /// return string data encode json original data
  @override
  String toString() {
    return json.encode(toJson());
  }

}""";

  classMessage += "\n\n${classMessages.join("\n\n")}";
  return classMessage;
}

String textToFunctionIsar({
  required String key,
  required value,
  required String returnType,
  required String className,
  bool isClass = false,
  bool isList = false,
  bool isUseClassName = false,
  String? comment,
  required void Function(String text) callback,
  required void Function(String text) paramFunction,
  required void Function(String text) paramJson,
  required void Function(String text) operatorData,
}) {
  comment ??= "";
  if (value is String) {
    value = json.encode(value);
  }
  String nameClass = key.camelCaseClass();
  if (isUseClassName) {
    nameClass = "${className}${key.camelCaseClass()}";
  }

  String nameMethod =
      key.replaceAll(RegExp(r"^(@|[0-9]+)", caseSensitive: false), "special_");

//   operatorData.call("""

//     if (key == "${key}") {
//       ${nameMethod} = value;
//     }

// """);

  if (isClass) {
    if (isList) {
      operatorData.call("""


    if (key == "${key}") {
      if (value is List<${nameClass}>) {
        ${nameMethod} = value;
      } else {
        
        ${nameMethod} = (value as List).map((state_data_procces) {
          ${nameClass} state_value_procces = ${nameClass}();
          (value as Map).forEach((key, value) {
            state_value_procces[key] = value;
          });
          return state_value_procces;
        }).toList().cast<${nameClass}>();

      }
    }


""");
      paramFunction.call("""
      List<${nameClass}?>? ${nameMethod},
""");
      paramJson.call("""
      "${key}": (${nameMethod} != null)?${nameMethod}.map((res) => res.toJson()).toList().cast<Map>():null,
""");
      callback.call("""
      try {
        if (rawData["${key}"] is List == false){
          ${nameMethod}  = null;
        }
        ${nameMethod} = (rawData["${key}"] as List).map((e) => ${nameClass}(e as $returnType)).toList().cast<${nameClass}>();
      } catch (e) {
        ${nameMethod}  = null;
      }
""");
      return """
  ${comment}
  List<${nameClass}> ${nameMethod} = [];

""";
    }
    operatorData.call("""


    if (key == "${key}") {
      ${nameMethod} = value;
    }


    if (key == "${key}") {
      if (value is ${nameClass}) {
        ${nameMethod} = value;
      } else {
        ${nameClass} state_value_procces = ${nameClass}();
        (value as Map).forEach((key, value) {
          state_value_procces[key] = value;
        });
        ${nameMethod} = state_value_procces;
      }
    }


""");
    paramFunction.call("""
      ${nameClass}? ${nameMethod},
""");
    paramJson.call("""
      "${key}": (${nameMethod} != null)?${nameMethod}.toJson(): null,
""");
    callback.call("""
      try {
        if (rawData["${key}"] is ${returnType} == false){
          ${nameMethod}  =  ${nameClass}({});
        }
        ${nameMethod} = ${nameClass}(rawData["${key}"] as $returnType);
      } catch (e) {
        ${nameMethod}  = ${nameClass}({}); 
      }
""");
    return """

  ${comment}
  ${nameClass} ${nameMethod} = ${nameClass}();

""";
  }

  operatorData.call("""


    if (key == "${key}") {
      ${nameMethod} = value;
    }


""");

  if (isList) {
    paramFunction.call("""
      List<${returnType}?>? ${nameMethod},
""");
    paramJson.call("""
      "${key}": ${nameMethod},
""");
    callback.call("""
      try {
        if (rawData["${key}"] is List == false){
          ${nameMethod}  = null;
        }
        ${nameMethod} = (rawData["${key}"] as List).cast<${returnType}>();
      } catch (e) {
        ${nameMethod}  = null;
      }
""");
    return """

  ${comment}
  List<${returnType}> ${nameMethod} = ${value};

""";
  }

  paramFunction.call("""
    $returnType? ${nameMethod},
""");
  paramJson.call("""
      "${key}": ${nameMethod},
""");
  callback.call("""
      try {
        if (rawData["${key}"] is ${returnType} == false){
          ${nameMethod}  = null;
        }
        ${nameMethod} = rawData["${key}"] as ${returnType};
      } catch (e) {
        ${nameMethod}  = null;
      }
""");
  return """

  ${comment}
  $returnType ${nameMethod} = ${value};

""";
}
